package Task::WWW::Search::Antiquarian::Czech;

# Pragmas.
use strict;
use warnings;

# Version.
our $VERSION = 0.01;

1;

__END__

=pod

=encoding utf8

=head1 NAME

Task::WWW::Search::Antiquarian::Czech - Install the WWW::Search modules for Czech antiquarian bookstores.

=head1 SYNOPSIS

 cpanm Task::WWW::Search::Antiquarian::Czech

=head1 SEE ALSO

L<WWW::Search::Antikvariat11CZ>,
L<WWW::Search::AntikvariatJudaicaCZ>,
L<WWW::Search::GalerieIlonkaCZ>,
L<WWW::Search::KacurCZ>,
L<WWW::Search::MelcerCZ>,
L<WWW::Search::ValentinskaCZ>.

=head1 REPOSITORY

L<https://github.com/tupinek/Task-WWW-Search-Antiquarian-Czech>

=head1 AUTHOR

Michal Špaček L<mailto:skim@cpan.org>

L<http://skim.cz>

=head1 LICENSE AND COPYRIGHT

 © 2015 Michal Špaček
 Artistic License
 BSD 2-Clause License

=head1 VERSION

0.01

=cut
